importance: Importance score computation for object JRF
(This file is a modified version of file importance.R contained in the R package randomForest.)
Description
Importance score computation for object JRF
(This file is a modified version of file importance.R contained in the R package randomForest.)Usage
importance(x, scale = TRUE)
Arguments
scale
either TRUE or FALSE
Value
- imp matrix of importance scores (
"imp")